@@ -17,8 +17,8 @@ In it's simplest form, consider this:
 >>>
 >>> dag = DAG((this, that, combine))
 >>> print(dag.synopsis_string())
-x,b -> that_ -> that
 a,b -> this_ -> this
+x,b -> that_ -> that
 this,that -> combine_ -> combine
 
 But don't be fooled: There's much more to it!
@@ -456,8 +456,8 @@ class DAG:
     >>>
     >>> dag = DAG((this, that, combine))
     >>> print(dag.synopsis_string())
-    x,b -> that_ -> that
     a,b -> this_ -> this
+    x,b -> that_ -> that
     this,that -> combine_ -> combine
 
     But what does it do?
@@ -465,15 +465,15 @@ class DAG:
     It's a callable, with a signature:
 
     >>> Sig(dag)  # doctest: +SKIP
-    <Sig (x, a, b=1)>
+    <Sig (a, x, b=1)>
 
     And when you call it, it executes the dag from the root values you give it and
     returns the leaf output values.
 
-    >>> dag(1, 2, 3)  # (a+b,x*b) == (2+3,1*3) == (5, 3)
-    (5, 3)
-    >>> dag(1, 2)  # (a+b,x*b) == (2+1,1*1) == (3, 1)
-    (3, 1)
+    >>> dag(1, 2, 3)  # (a+b,x*b) == (1+3,2*3) == (4, 6)
+    (4, 6)
+    >>> dag(1, 2)  # (a+b,x*b) == (1+1,2*1) == (2, 2)
+    (2, 2)
 
     The above DAG was created straight from the functions, using only the names of the
     functions and their arguments to define how to hook the network up.
@@ -541,8 +541,8 @@ class DAG:
         ...     y=lambda x, _0: x + _0  # _0 refers to first arg (lambda a: a * 2)
         ... )
         >>> print(dag.synopsis_string())
-         -> x_ -> x
         a -> _0_ -> _0
+         -> x_ -> x
         x,_0 -> y_ -> y
         >>> dag(3)
         16
@@ -688,12 +688,12 @@ class DAG:
         >>> dag = DAG([f, g, h, i, j, k, l])
         >>> print(dag.synopsis_string())
         u,v -> f_ -> f
-        f,w -> h_ -> h
-        h,x -> j_ -> j
         f -> g_ -> g
+        f,w -> h_ -> h
         g,h -> i_ -> i
-        i,j -> l_ -> l
+        h,x -> j_ -> j
         i -> k_ -> k
+        i,j -> l_ -> l
 
         A little util to get consistent prints:
 
@@ -783,8 +783,8 @@ class DAG:
         >>> dag = DAG([f, g, h])
         >>> from inspect import signature
         >>> str(signature(dag))
-        '(c, a, b, d=4)'
-        >>> dag(3, 1, 2, 4)  # == (3 * 4) - (1 + 2) == 12 - 3 == 9
+        '(a, b, c, d=4)'
+        >>> dag(1, 2, 3, 4)  # == (3 * 4) - (1 + 2) == 12 - 3 == 9
         9
         >>> dag(c=3, a=1, b=2, d=4)  # same as above
         9
@@ -1028,10 +1028,10 @@ class DAG:
 
         >>> dag = DAG(list) + DAG(tuple)
         >>> print(dag.synopsis_string(bind_info='hybrid'))
-        iterable -> tuple_ -> tuple
         iterable -> list_ -> list
+        iterable -> tuple_ -> tuple
         >>> dag([1,2,3])
-        ((1, 2, 3), [1, 2, 3])
+        ([1, 2, 3], (1, 2, 3))
         """
         if isinstance(other, DAG):
             other = list(other.func_nodes)
@@ -1057,14 +1057,14 @@ class DAG:
         >>> three_funcs = DAG([f, g, h])
         >>> assert (
         ...     three_funcs(x=1, c=2, a=3, b=4)
-        ...     == (1, 2, 7)
-        ...     == (h(x=1), g(c=2), f(a=3, b=4))
-        ...     == (1 ** 1, 2 * 1, 3 + 4)
+        ...     == (7, 2, 1)
+        ...     == (f(a=3, b=4), g(c=2), h(x=1))
+        ...     == (3 + 4, 2*1, 1** 1)
         ... )
         >>> print(three_funcs.synopsis_string())
-        x,y -> h_ -> h
-        c,d -> g_ -> g
         a,b -> f_ -> f
+        c,d -> g_ -> g
+        x,y -> h_ -> h
         >>> hg = three_funcs.add_edge('h', 'g')
         >>> assert (
         ...     hg(a=3, b=4, x=1)
@@ -1115,8 +1115,8 @@ class DAG:
         ... )
         >>>
         >>> print(f_of_g_and_h.synopsis_string())
-        x,y -> h_ -> h
         c,d -> g_ -> g
+        x,y -> h_ -> h
         g,h -> f_ -> f
 
         See Also ``DAG.add_edges`` to add multiple edges at once
@@ -1230,40 +1230,40 @@ class DAG:
         ...
         >>> dag2 = DAG([f, g, h], name='arithmetic')
         >>> dag2
-        DAG(func_nodes=[FuncNode(c,d -> g_ -> g), FuncNode(a,b -> f_ -> f), FuncNode(f,g -> h_ -> h)], name='arithmetic')
+        DAG(func_nodes=[FuncNode(a,b -> f_ -> f), FuncNode(c,d -> g_ -> g), FuncNode(f,g -> h_ -> h)], name='arithmetic')
         >>> str(signature(dag2))
-        '(c, a, b, d=4)'
+        '(a, b, c, d=4)'
         >>> dag2(1,2,3)
-        -1
+        9
         >>>
         >>> debugger = dag2.debugger()
         >>> str(signature(debugger))
-        '(c, a, b, d=4)'
+        '(a, b, c, d=4)'
         >>> d = debugger(1,2,3)
         >>> next(d)  # doctest: +NORMALIZE_WHITESPACE
         0 --------------------------------------------------------------
-            func_node=FuncNode(c,d -> g_ -> g)
-            scope={'c': 1, 'a': 2, 'b': 3, 'd': 4, 'g': 4}
-        4
+            func_node=FuncNode(a,b -> f_ -> f)
+            scope={'a': 1, 'b': 2, 'c': 3, 'd': 4, 'f': 3}
+        3
         >>> next(d)  # doctest: +NORMALIZE_WHITESPACE
         1 --------------------------------------------------------------
-            func_node=FuncNode(a,b -> f_ -> f)
-            scope={'c': 1, 'a': 2, 'b': 3, 'd': 4, 'g': 4, 'f': 5}
-        5
+            func_node=FuncNode(c,d -> g_ -> g)
+            scope={'a': 1, 'b': 2, 'c': 3, 'd': 4, 'f': 3, 'g': 12}
+        12
 
         ... and so on. You can also choose to run every step all at once, collecting
         the ``feedback`` outputs of each step in a list, like this:
 
         >>> feedback_outputs = list(debugger(1,2,3))  # doctest: +NORMALIZE_WHITESPACE
         0 --------------------------------------------------------------
-            func_node=FuncNode(c,d -> g_ -> g)
-            scope={'c': 1, 'a': 2, 'b': 3, 'd': 4, 'g': 4}
-        1 --------------------------------------------------------------
             func_node=FuncNode(a,b -> f_ -> f)
-            scope={'c': 1, 'a': 2, 'b': 3, 'd': 4, 'g': 4, 'f': 5}
+            scope={'a': 1, 'b': 2, 'c': 3, 'd': 4, 'f': 3}
+        1 --------------------------------------------------------------
+            func_node=FuncNode(c,d -> g_ -> g)
+            scope={'a': 1, 'b': 2, 'c': 3, 'd': 4, 'f': 3, 'g': 12}
         2 --------------------------------------------------------------
             func_node=FuncNode(f,g -> h_ -> h)
-            scope={'c': 1, 'a': 2, 'b': 3, 'd': 4, 'g': 4, 'f': 5, 'h': -1}
+            scope={'a': 1, 'b': 2, 'c': 3, 'd': 4, 'f': 3, 'g': 12, 'h': 9}
 
         """
         # TODO: Add feedback callable validation
@@ -1641,8 +1641,8 @@ def ch_names(func_nodes: DagAble = None, *, renamer: Renamer = numbered_suffix_r
     This is what the dag looks like:
 
     >>> print_dag_string(dag)
-    x=a -> g -> c
     a -> f -> b
+    x=a -> g -> c
     b,y=c -> h -> d
 
     Now, if rename the vars of the ``dag`` without further specifying how, all of our
@@ -1659,8 +1659,8 @@ def ch_names(func_nodes: DagAble = None, *, renamer: Renamer = numbered_suffix_r
 
     >>> another_new_data = ch_names(new_dag)
     >>> print_dag_string(another_new_data)
-    x=a_2 -> g_2 -> c_2
     a=a_2 -> f_2 -> b_2
+    x=a_2 -> g_2 -> c_2
     b=b_2,y=c_2 -> h_2 -> d_2
 
     If we specify a string for the ``renamer`` argument, it will be used to suffix all
@@ -1684,7 +1684,7 @@ def ch_names(func_nodes: DagAble = None, *, renamer: Renamer = numbered_suffix_r
     have the effect of not changing that identifier.
 
     >>> ch_names(dag.func_nodes, renamer=lambda x: x.upper() if x in 'abc' else None)
-    [FuncNode(x=A -> g -> C), FuncNode(a=A -> f -> B), FuncNode(b=B,y=C -> h -> d)]
+    [FuncNode(a=A -> f -> B), FuncNode(x=A -> g -> C), FuncNode(b=B,y=C -> h -> d)]
 
     If you want to rename the nodes with an explicit mapping, you can do so by
     specifying this mapping as your renamer
