@@ -485,6 +485,41 @@ def _extract_name_from_single_func_def(src: str, default=None):
 FuncSource = Union[Callable[[str], Callable], Mapping[str, Callable]]
 
 
+@double_up_as_factory
+def code_to_fnodes(
+    src=None,
+    *,
+    func_src: FuncSource = dlft_factory_to_func,
+    use_place_holder_fallback=False,
+) -> Tuple[FuncNode]:
+    """Get func_nodes from src code"""
+    func_src = _ensure_func_src(func_src, use_place_holder_fallback)
+    # Pass on to _code_to_fnodes to get func nodes iterable needed to make DAG
+    return tuple(_code_to_fnodes(src, func_src))
+
+
+@double_up_as_factory
+def code_to_dag(
+    src=None,
+    *,
+    func_src: FuncSource = dlft_factory_to_func,
+    use_place_holder_fallback=False,
+    name: str = None,
+) -> DAG:
+    """Get a ``meshed.DAG`` from src code"""
+    fnodes = code_to_fnodes(
+        src, func_src=func_src, use_place_holder_fallback=use_place_holder_fallback
+    )
+    return DAG(fnodes, name=_ensure_name(name, src))
+
+
+def code_to_digraph(src):
+    return code_to_dag(src).dot_digraph()
+
+
+simple_code_to_digraph = code_to_digraph  # back-compatability alias
+
+
 def _ensure_func_src(
     func_src: FuncSource, use_place_holder_fallback=False
 ) -> Callable[[str], Callable]:
@@ -499,33 +534,13 @@ def _ensure_func_src(
     return func_src
 
 
-@double_up_as_factory
-def code_to_dag(
-    src=None,
-    *,
-    func_src: FuncSource = dlft_factory_to_func,
-    use_place_holder_fallback=False,
-    name: str = None,
-) -> DAG:
-    """Get a ``meshed.DAG`` from src code"""
-    func_src = _ensure_func_src(func_src, use_place_holder_fallback)
-    # Get a name for the dag (if src is a str
+def _ensure_name(name, src):
     if name is None:
         if isinstance(src, str):
             name = _extract_name_from_single_func_def(src, 'dag_made_from_code_parsing')
         else:
             name = name_of_obj(src)
-    # Pass on to _code_to_fnodes to get func nodes iterable needed to make DAG
-    fnodes = _code_to_fnodes(src, func_src)
-    fnodes = list(fnodes)
-    return DAG(fnodes, name=name)
-
-
-def code_to_digraph(src):
-    return code_to_dag(src).dot_digraph()
-
-
-simple_code_to_digraph = code_to_digraph  # back-compatability alias
+    return name
 
 
 # SB stuff, not used, so comment-out deprecating
